# csdb <a href="https://niphr.github.io/csdb/"><img src="man/figures/logo.png" align="right" width="120" /></a>

[![CRAN status](https://www.r-pkg.org/badges/version/csdb)](https://cran.r-project.org/package=csdb)
[![CRAN downloads](https://cranlogs.r-pkg.org/badges/csdb)](https://cran.r-project.org/package=csdb)

## Overview 

[csdb](https://niphr.github.io/csdb/) provides an abstracted system for easily working with databases with large datasets.

Read the introduction vignette [here](https://niphr.github.io/csdb/articles/csdb.html) or run `help(package="csdb")`.
