% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/r6_DBConnection_v9.R
\name{csdb_get_auth_hook}
\alias{csdb_get_auth_hook}
\title{Get the current authentication hook}
\usage{
csdb_get_auth_hook()
}
\value{
The current auth hook function, or NULL if none is set.
}
\description{
Returns the currently registered authentication hook function.
}
